package sgc.portal.cs.cs0402.persistence;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cs.cs0402.dto.CS04020001USearch;


import java.util.List;
import java.util.Map;

@Mapper
public interface CS04020001UMapper {
	
	//동적조회 세팅
	List<EasyHashMap<String, Object>> selectHeaderUpList(CS04020001USearch search);
	List<EasyHashMap<String, Object>> selectHeaderDownList(CS04020001USearch search);
	List<EasyHashMap<String, Object>> selectHeaderCountList(CS04020001USearch search);
	String selectName(CS04020001USearch search);
	
	//담당자별주간보고 조회
	List<EasyHashMap<String, Object>> selectTotalTcsWeekWorkList(CS04020001USearch search);
	EasyHashMap<String, Object> selectChooseTcsWeekWorkList(CS04020001USearch search);
	List<EasyHashMap<String, Object>> selectChooseTcsWeekWorkRptList1(CS04020001USearch search);
	List<EasyHashMap<String, Object>> selectChooseTcsWeekWorkRptList2(CS04020001USearch search);
	String selectChooseTcsWeekWorkFirstDay(CS04020001USearch search);
}
